@@ -3,20 +3,21 @@ from stjames import Molecule
 
 import rowan
 
-# rowan.api_key = ""
+# Set ROWAN_API_KEY environment variable to your API key or set rowan.api_key directly
+# rowan.api_key = "rowan-sk..."
 
-conformer_dependent_redox_folder = rowan.create_folder(name="Conformer dependent redox results")
+conformer_dependent_redox_folder = rowan.create_folder(name="Conformer dependent redox workflows")
 
-result = rowan.submit_conformer_search_workflow(
+workflow = rowan.submit_conformer_search_workflow(
     initial_molecule=Molecule.from_smiles("CC(C)Cc1ccc(C(=O)c2ccc(O)cc2)cc1"),
     folder_uuid=conformer_dependent_redox_folder.uuid,
 )
-result.wait_for_result()
-result.fetch_latest(in_place=True)
+print(f"View workflow privately at: https://labs.rowansci.com/workflow/{workflow.uuid}")
+workflow.wait_for_result().fetch_latest(in_place=True)
 
 redox_potential_workflows = []
 
-for conformer in result.data["conformer_uuids"][:10]:
+for conformer in workflow.data["conformer_uuids"][:10]:
     uuid = conformer[0]
     molecule = rowan.retrieve_calculation_molecules(uuid)[0]
     stjames_molecule = stjames.Molecule.model_validate(molecule)
@@ -30,7 +31,7 @@ for conformer in result.data["conformer_uuids"][:10]:
     )
 
 for workflow in redox_potential_workflows:
-    workflow.wait_for_result()
+    workflow.wait_for_workflow()
     workflow.fetch_latest(in_place=True)
 
 
