@@ -21,11 +21,13 @@ from stjames import Molecule
 
 import rowan
 
-# rowan.api_key = ""
+# Set ROWAN_API_KEY environment variable to your API key or set rowan.api_key directly
+# rowan.api_key = "rowan-sk..."
 
-# Run calculation remotely
-result = rowan.submit_conformer_search_workflow(
+workflow = rowan.submit_conformer_search_workflow(
     initial_molecule=Molecule.from_smiles("CCOCC"),
 )
 
-print(result.wait_for_result().fetch_latest(in_place=True))
+print(f"View workflow privately at: https://labs.rowansci.com/workflow/{workflow.uuid}")
+workflow.wait_for_result().fetch_latest(in_place=True)
+print(workflow)
